@@ -11,22 +11,23 @@
 
 from typing import Optional
 
-from PySide6.QtCore import Slot
+from PySide6.QtCore import Slot, QObject
 
 from pygpt_net.core.bridge import BridgeContext
 from pygpt_net.core.events import RenderEvent
 from pygpt_net.core.types import MODE_ASSISTANT
 from pygpt_net.item.ctx import CtxItem
 
-from .handler.stream_worker import StreamWorker
+from .handler.worker import StreamWorker
 
-class Stream:
+class Stream(QObject):
     def __init__(self, window=None):
         """
         Stream controller
 
         :param window: Window instance
         """
+        super().__init__()
         self.window = window
         self.ctx = None
         self.mode = None
@@ -37,6 +38,7 @@ class Stream:
         self.internal = False
         self.context = None
         self.extra = {}
+        self.instance = None
 
     def append(
             self,
@@ -67,11 +69,16 @@ class Stream:
         self.context = context
         self.extra = extra if extra is not None else {}
 
+        # cache the get renderer instance method
+        if self.instance is None:
+            self.instance = self.window.controller.chat.render.instance # callable
+
         worker = StreamWorker(ctx, self.window)
         worker.stream = ctx.stream
         worker.signals.eventReady.connect(self.handleEvent)
         worker.signals.errorOccurred.connect(self.handleError)
         worker.signals.end.connect(self.handleEnd)
+        worker.signals.chunk.connect(self.handleChunk)
         ctx.stream = None
         self.worker = worker
 
@@ -85,31 +92,56 @@ class Stream:
 
         :param ctx: Context item
         """
-        self.window.controller.ui.update_tokens()
+        controller = self.window.controller
+        controller.ui.update_tokens()
 
         data = {"meta": self.ctx.meta, "ctx": self.ctx}
         event = RenderEvent(RenderEvent.STREAM_END, data)
         self.window.dispatch(event)
-        self.window.controller.chat.output.handle_after(
+        controller.chat.output.handle_after(
             ctx=ctx,
             mode=self.mode,
             stream=True,
         )
 
         if self.mode == MODE_ASSISTANT:
-            self.window.controller.assistant.threads.handle_output_message_after_stream(ctx)
+            controller.assistant.threads.handle_output_message_after_stream(ctx)
         else:
             if self.is_response:
-                self.window.controller.chat.response.post_handle(
+                controller.chat.response.post_handle(
                     ctx=ctx,
                     mode=self.mode,
                     stream=True,
                     reply=self.reply,
-                    internal=self.internal
+                    internal=self.internal,
                 )
 
         self.worker = None
 
+    @Slot(object, str, bool)
+    def handleChunk(
+            self,
+            ctx: CtxItem,
+            chunk: str,
+            begin: bool = False
+    ):
+        """
+        Handle a chunk of data in the stream
+
+        :param ctx: Context item
+        :param chunk: Chunk of data
+        :param begin: Whether this is the beginning of the stream
+        """
+        # direct call to the renderer to avoid overhead of event queue
+        self.instance().append_chunk(
+            ctx.meta,
+            ctx,
+            chunk,
+            begin,
+        )
+        chunk = None  # free reference
+
+    @Slot(object)
     def handleEvent(self, event):
         """
         Slot for handling stream events
@@ -118,6 +150,7 @@ class Stream:
         """
         self.window.dispatch(event)
 
+    @Slot(object)
     def handleError(self, error):
         """
         Slot for handling stream errors
