@@ -8,10 +8,11 @@
 # Created By  : Marcin Szczygliński                  #
 # Updated Date: 2025.08.24 23:00:00                  #
 # ================================================== #
-
+import gc
 from typing import Any, Optional, Tuple
 
-from PySide6.QtCore import QTimer
+from PySide6.QtCore import QTimer, QUrl
+from PySide6.QtWebEngineCore import QWebEnginePage
 
 from pygpt_net.core.events import AppEvent, RenderEvent
 from pygpt_net.core.tabs.tab import Tab
@@ -133,9 +134,15 @@ class Tabs:
 
     def reload(self):
         """Reload tabs"""
+        columns = self.window.ui.layout.columns
+        for col in columns:
+            col.setUpdatesEnabled(False)
+        self.window.core.tabs.remove_all()
         self.window.core.tabs.reload()
         self.window.dispatch(RenderEvent(RenderEvent.PREPARE))
         self.debug()
+        for col in columns:
+            col.setUpdatesEnabled(True)
 
     def reload_after(self):
         """Reload tabs after"""
