@@ -6,20 +6,21 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2025.08.15 03:00:00                  #
+# Updated Date: 2025.08.23 15:00:00                  #
 # ================================================== #
 
 from typing import Optional
 
 from PySide6.QtGui import QColor
 
+from pygpt_net.core.types import MODE_IMAGE
+from pygpt_net.core.events import BaseEvent, Event
 from pygpt_net.utils import trans
 
 from .mode import Mode
 from .tabs import Tabs
 from .vision import Vision
 
-
 class UI:
     def __init__(self, window=None):
         """
@@ -64,6 +65,21 @@ class UI:
         self.update_tokens()
         self.vision.update()
         self.window.controller.agent.legacy.update()
+        self.img_update_available_resolutions()
+
+    def handle(self, event: BaseEvent):
+        """
+        Handle events
+
+        :param event: BaseEvent: Event to handle
+        """
+        name = event.name
+
+        # on input begin
+        if name == Event.INPUT_BEGIN:
+            self.tabs.switch_to_first_chat()  # switch to first active chat tab
+        elif name == Event.CTX_END:
+            self.update_tokens()  # update UI
 
     def get_colors(self) -> dict:
         """
@@ -201,4 +217,20 @@ class UI:
     def on_global_stop(self):
         """Global stop button action"""
         if self.stop_action == "idx":
-            self.window.controller.idx.force_stop()
\ No newline at end of file
+            self.window.controller.idx.force_stop()
+
+    def img_update_available_resolutions(self):
+        """Update available resolutions for images"""
+        mode = self.window.core.config.get('mode')
+        if mode != MODE_IMAGE:
+            return
+        model = self.window.core.config.get('model')
+        keys = self.window.core.image.get_available_resolutions(model)
+        current = self.window.core.config.get('img_resolution', '1024x1024')
+        self.window.ui.config['global']['img_resolution'].set_keys(keys, lock=False)
+        self.window.controller.config.apply_value(
+            parent_id="global",
+            key="img_resolution",
+            option=self.window.core.image.get_resolution_option(),
+            value=current,
+        )
\ No newline at end of file
