@@ -6,7 +6,7 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2025.08.12 00:00:00                  #
+# Updated Date: 2025.08.24 02:00:00                  #
 # ================================================== #
 
 from typing import List
@@ -188,8 +188,8 @@ class Evaluation:
         i = 0
         for ctx in history:
             # if next input (but not last) then clear outputs - use only output after last user input
-            if self.is_input(ctx) and i < len(history) - 1:
-                outputs.clear()
+            # if self.is_input(ctx) and i < len(history) - 1:
+                # outputs.clear()
 
             if self.is_output(ctx):
                 if ctx.output:
@@ -212,7 +212,7 @@ class Evaluation:
         return prompt.format(
             task=main_task,
             input=last_input,
-            output=final_response
+            output=final_response,
         )
 
     def get_prompt_complete(self, history: List[CtxItem]) -> str:
@@ -229,7 +229,7 @@ class Evaluation:
         return prompt.format(
             task=main_task,
             input=last_input,
-            output=final_response
+            output=final_response,
         )
 
     def get_tools(self) -> List[FunctionTool]:
