@@ -6,7 +6,7 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2025.08.12 19:00:00                  #
+# Updated Date: 2025.08.24 03:00:00                  #
 # ================================================== #
 
 from typing import Dict, Any, List
@@ -59,17 +59,20 @@ class OpenAIWorkflow(BaseRunner):
         if self.is_stopped():
             return True  # abort if stopped
 
+        if "llm" in agent_kwargs:
+            agent_kwargs["llm"] = None  # clear llm if provided, as it is not used in OpenAI workflow
+
         self.set_busy(signals)
 
         # append input to messages
         context = agent_kwargs.get("context", BridgeContext())
         attachments = context.attachments if context else []
         history, previous_response_id = self.window.core.agents.memory.prepare_openai(context)
-        msg = self.window.core.gpt.vision.build_agent_input(prompt, attachments)  # build content with attachments
-        self.window.core.gpt.vision.append_images(ctx)  # append images to ctx if provided
+        msg = self.window.core.api.openai.vision.build_agent_input(prompt, attachments)  # build content with attachments
+        self.window.core.api.openai.vision.append_images(ctx)  # append images to ctx if provided
         history = history + msg
 
-        # callbacks
+        # ------------ callbacks ----------------
         def on_step(
                 ctx: CtxItem,
                 begin: bool = False
@@ -136,6 +139,16 @@ class OpenAIWorkflow(BaseRunner):
                 self.send_stream(ctx, signals, False)
                 self.end_stream(ctx, signals)
 
+            # fix: prevent race condition with next context if feedback after response
+            if finish and input == output:
+                ctx.extra["agent_finish"] = True  # mark as finished and ready for evaluation
+                ctx.extra["agent_finish_evaluate"] = True  # mark as feedback response (ignored in loop evaluation)
+                if stream:
+                    self.send_stream(ctx, signals, False)
+                    self.end_stream(ctx, signals)
+                self.send_response(ctx, signals, KernelEvent.APPEND_DATA)
+                return ctx
+
             # create and return next context item
             next_ctx = self.add_next_ctx(ctx)
             next_ctx.set_input(input)
@@ -158,7 +171,8 @@ class OpenAIWorkflow(BaseRunner):
             self.set_idle(signals)
             self.set_error(error)
 
-        # callbacks
+        # ------------ / callbacks ----------------
+
         bridge = ConnectionContext(
             stopped=self.is_stopped,
             on_step=on_step,
