@@ -6,7 +6,7 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2025.08.15 23:00:00                  #
+# Updated Date: 2025.09.04 00:00:00                  #
 # ================================================== #
 
 import time
@@ -59,7 +59,7 @@ class Bridge:
         if self.window.controller.kernel.stopped():
             return False
 
-        allowed_model_change = MODE_VISION
+        allowed_model_change = [MODE_CHAT]
         is_virtual = False
         force_sync = False
 
@@ -130,7 +130,6 @@ class Bridge:
                 self.window.core.debug.debug(str(debug))
 
         self.apply_rate_limit()  # apply RPM limit
-        self.last_context = weakref.ref(context)  # store last context for call (debug)
 
         if extra is None:
             extra = {}
@@ -150,6 +149,7 @@ class Bridge:
         # async call
         self.window.core.debug.info("[bridge] Starting worker (async)...")
         self.window.threadpool.start(worker)
+        self.worker = worker
         return True
 
     def request_next(
@@ -177,6 +177,7 @@ class Bridge:
 
         # async call
         self.window.threadpool.start(worker)
+        self.worker = worker
         return True
 
     def call(
@@ -200,9 +201,6 @@ class Bridge:
                 debug = {k: str(v) for k, v in context.to_dict().items()}
                 self.window.core.debug.debug(str(debug))
 
-        # --- DEBUG ONLY ---
-        self.last_context_quick = weakref.ref(context)  # store last context for quick call (debug)
-
         if context.model is not None:
             # check if model is supported by OpenAI API, if not then try to use llama-index or langchain call
             if not context.model.is_supported(MODE_CHAT):
@@ -252,7 +250,7 @@ class Bridge:
                         context.mode = MODE_RESEARCH
 
         # default: OpenAI API call
-        return self.window.core.gpt.quick_call(
+        return self.window.core.api.openai.quick_call(
             context=context,
             extra=extra,
         )
@@ -266,6 +264,7 @@ class Bridge:
         worker = BridgeWorker()
         worker.window = self.window
         worker.signals.response.connect(self.window.controller.kernel.listener)
+        worker.rt_signals = self.window.controller.realtime.signals  # Realtime signals
         return worker
 
     def apply_rate_limit(self):
