@@ -6,12 +6,9 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2024.03.06 02:00:00                  #
+# Updated Date: 2025.09.14 20:00:00                  #
 # ================================================== #
 
-import datetime
-import os
-
 
 class DatabaseDebug:
     def __init__(self, window=None):
