@@ -6,7 +6,7 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2025.08.06 01:00:00                  #
+# Updated Date: 2025.09.15 01:00:00                  #
 # ================================================== #
 
 from typing import Optional, List, Dict
@@ -69,7 +69,7 @@ class PerplexityLLM(BaseLLM):
             stream: bool = False
     ) -> LlamaBaseLLM:
         """
-        Return LLM provider instance for llama
+        Return LLM provider instance for llama (Perplexity)
 
         :param window: window instance
         :param model: model instance
@@ -77,12 +77,73 @@ class PerplexityLLM(BaseLLM):
         :return: LLM provider instance
         """
         from llama_index.llms.perplexity import Perplexity as LlamaPerplexity
+        from .utils import ProxyEnv
+
+        cfg = window.core.config
         args = self.parse_args(model.llama_index, window)
-        if "api_key" not in args:
-            args["api_key"] = window.core.config.get("api_key_perplexity", "")
+
+        if "api_key" not in args or not args["api_key"]:
+            args["api_key"] = cfg.get("api_key_perplexity", "")
         if "model" not in args:
             args["model"] = model.id
-        return LlamaPerplexity(**args)
+
+        custom_base = cfg.get("api_endpoint_perplexity", "").strip()
+        if custom_base and "api_base" not in args:
+            args["api_base"] = custom_base
+
+        # httpx.Client/AsyncClient (proxy, timeout, socks etc.)
+        try:
+            args_injected = self.inject_llamaindex_http_clients(dict(args), cfg)
+            return LlamaPerplexity(**args_injected)
+        except TypeError:
+            return LlamaPerplexity(**args)
+
+        # -----------------------------------
+        # TODO: fallback
+        proxy = cfg.get("api_proxy") or cfg.get("api_native_perplexity.proxy")
+
+        class PerplexityWithProxy(LlamaPerplexity):
+            def __init__(self, *a, **kw):
+                super().__init__(*a, **kw)
+                self._proxy = proxy
+
+            # sync
+            def complete(self, *a, **kw):
+                with ProxyEnv(self._proxy):
+                    return super().complete(*a, **kw)
+
+            def chat(self, *a, **kw):
+                with ProxyEnv(self._proxy):
+                    return super().chat(*a, **kw)
+
+            def stream_complete(self, *a, **kw):
+                with ProxyEnv(self._proxy):
+                    return super().stream_complete(*a, **kw)
+
+            def stream_chat(self, *a, **kw):
+                with ProxyEnv(self._proxy):
+                    return super().stream_chat(*a, **kw)
+
+            # async
+            async def acomplete(self, *a, **kw):
+                with ProxyEnv(self._proxy):
+                    return await super().acomplete(*a, **kw)
+
+            async def achat(self, *a, **kw):
+                with ProxyEnv(self._proxy):
+                    return await super().achat(*a, **kw)
+
+            async def astream_complete(self, *a, **kw):
+                with ProxyEnv(self._proxy):
+                    async for chunk in super().astream_complete(*a, **kw):
+                        yield chunk
+
+            async def astream_chat(self, *a, **kw):
+                with ProxyEnv(self._proxy):
+                    async for chunk in super().astream_chat(*a, **kw):
+                        yield chunk
+
+        return PerplexityWithProxy(**args)
 
     def llama_multimodal(
             self,
