@@ -31,7 +31,7 @@ class TabBody(QTabWidget):
         """
         Clean up on delete
         """
-        if self.on_delete:
+        if self.on_delete and callable(self.on_delete):
             self.on_delete(self)
         self.delete_refs()
 
@@ -49,10 +49,18 @@ class TabBody(QTabWidget):
         Delete all references to widgets in this tab
         """
         for ref in self.refs:
+            if ref is None:
+                continue
             if ref and hasattr(ref, 'on_delete'):
-                ref.on_delete()
+                try:
+                    ref.on_delete()
+                except Exception:
+                    pass
             if ref and hasattr(ref, 'deleteLater'):
-                ref.deleteLater()
+                try:
+                    ref.deleteLater()
+                except Exception:
+                    pass
         del self.refs[:]
 
     def delete_ref(self, widget: Any) -> None:
